@@ -1,23 +1,16 @@
-from neuromodcell.optimisation_setup import optimisation_setup
+from neuromodcell.optimisation_setup import OptimisationSetup
 
 
-class optimisation_setup_seclamp(optimisation_setup):
-
+class OptimisationSetupSeclamp(OptimisationSetup):
 
     def __init__(self, modulation_setup):
-
-
         self.seclamp = list()
         self.c_save = dict()
 
-        super(optimisation_setup_seclamp,self).__init__(modulation_setup=modulation_setup)
-        
-
+        super(OptimisationSetupSeclamp, self).__init__(modulation_setup=modulation_setup)
 
     def current_save(self):
-
         for i, cell in self.neurons.items():
-
             seclamp = self.sim.neuron.h.SEClamp(cell.icell.soma[0](0.5))
             seclamp.rs = 1e-6
             seclamp.dur1 = self.modulation_setup["tstop"]
@@ -29,11 +22,3 @@ class optimisation_setup_seclamp(optimisation_setup):
             self.seclamp.append(seclamp)
 
         return self.c_save
-        
-
-        
-
-    
-
-
-         
